![test and build](https://github.com/felixocker/focker-pypitest/actions/workflows/publish-to-testpypi.yml/badge.svg)
![pypi release](https://github.com/felixocker/focker-pypitest/actions/workflows/publish-to-pypi.yml/badge.svg)
[![PyPI](https://img.shields.io/pypi/v/focker-pypitest)](https://pypi.org/project/focker-pypitest/)
[![License](https://img.shields.io/badge/license-GPLv3-blue)](https://www.gnu.org/licenses/gpl-3.0.html)

# pypitest

this repo serves as a reference and for testing CI/CD pipelines, especially via GitHub actions 
